@@ -42,6 +42,8 @@ struct _XfceRandrPrivate
     /* cache for the output/mode info */
     XRROutputInfo **output_info;
     XfceRRMode **modes;
+    RROutput *rr_outputs;
+
     /* SHA-1 checksum of the EDID */
     gchar **edid;
 };
@@ -51,7 +53,7 @@ struct _XfceRandrPrivate
 static gchar *
 xfce_randr_friendly_name (XfceRandr *randr,
                           guint output,
-                          guint output_rr_id);
+                          RROutput rr_output);
 
 
 
@@ -105,16 +107,10 @@ xfce_randr_list_supported_modes (XRRScreenResources *resources,
         {
             if (output_info->modes[n] == resources->modes[m].id)
             {
-                gdouble v_total = resources->modes[m].vTotal;
-                if (resources->modes[m].modeFlags & RR_DoubleScan)
-                    v_total *= 2.0;
-                if (resources->modes[m].modeFlags & RR_Interlace)
-                    v_total /= 2.0;
-
                 modes[n].width = resources->modes[m].width;
                 modes[n].height = resources->modes[m].height;
-                modes[n].rate = (gdouble) resources->modes[m].dotClock
-                                / ((gdouble) resources->modes[m].hTotal * v_total);
+                modes[n].rate = xfce_randr_calculate_refresh_rate (resources->modes[m]);
+                modes[n].flags = resources->modes[m].modeFlags;
 
                 break;
             }
@@ -164,7 +160,7 @@ xfce_randr_populate (XfceRandr *randr,
     XRRCrtcInfo *crtc_info;
     gint n;
     guint m, connected;
-    guint *output_ids = NULL;
+    RROutput *rr_outputs = NULL;
 
     g_return_if_fail (randr != NULL);
     g_return_if_fail (randr->priv != NULL);
@@ -172,7 +168,7 @@ xfce_randr_populate (XfceRandr *randr,
 
     /* prepare the temporary cache */
     outputs = g_ptr_array_new ();
-    output_ids = g_malloc0 (randr->priv->resources->noutput * sizeof (guint));
+    rr_outputs = g_new0 (RROutput, randr->priv->resources->noutput);
 
     /* walk the outputs */
     connected = 0;
@@ -190,7 +186,7 @@ xfce_randr_populate (XfceRandr *randr,
         }
         else
         {
-            output_ids[connected] = n;
+            rr_outputs[connected] = randr->priv->resources->outputs[n];
             connected++;
         }
 
@@ -201,6 +197,7 @@ xfce_randr_populate (XfceRandr *randr,
     /* migrate the temporary cache */
     randr->noutput = outputs->len;
     randr->priv->output_info = (XRROutputInfo **) g_ptr_array_free (outputs, FALSE);
+    randr->priv->rr_outputs = rr_outputs;
 
     /* allocate final space for the settings */
     randr->mode = g_new0 (RRMode, randr->noutput);
@@ -222,7 +219,7 @@ xfce_randr_populate (XfceRandr *randr,
         randr->priv->modes[m] = xfce_randr_list_supported_modes (randr->priv->resources, randr->priv->output_info[m]);
 
         /* find the primary screen */
-        if (XRRGetOutputPrimary (xdisplay, GDK_WINDOW_XID (root_window)) == randr->priv->resources->outputs[output_ids[m]])
+        if (XRRGetOutputPrimary (xdisplay, GDK_WINDOW_XID (root_window)) == rr_outputs[m])
             randr->status[m] = XFCE_OUTPUT_STATUS_PRIMARY;
         else
             randr->status[m] = XFCE_OUTPUT_STATUS_SECONDARY;
@@ -256,7 +253,7 @@ xfce_randr_populate (XfceRandr *randr,
         }
 
         /* fill in the name used by the UI */
-        randr->friendly_name[m] = xfce_randr_friendly_name (randr, m, output_ids[m]);
+        randr->friendly_name[m] = xfce_randr_friendly_name (randr, m, rr_outputs[m]);
 
         /* Replace spaces with underscore in name for xfconf compatibility */
         g_strcanon (randr->priv->output_info[m]->name,
@@ -264,8 +261,6 @@ xfce_randr_populate (XfceRandr *randr,
     }
     /* populate mirrored details */
     xfce_randr_guess_relations (randr);
-
-    g_free (output_ids);
 }
 
 
@@ -346,6 +341,7 @@ xfce_randr_cleanup (XfceRandr *randr)
     g_free (randr->position);
     g_free (randr->mirrored);
     g_free (randr->priv->output_info);
+    g_free (randr->priv->rr_outputs);
 }
 
 
@@ -435,6 +431,10 @@ xfce_randr_save_output (XfceRandr *randr,
                 randr->priv->output_info[output]->name);
     xfconf_channel_set_double (channel, property, mode->rate);
 
+    g_snprintf (property, sizeof (property), "/%s/%s/ModeFlags", scheme,
+                randr->priv->output_info[output]->name);
+    xfconf_channel_set_uint64 (channel, property, mode->flags);
+
     /* convert the rotation into degrees */
     switch (randr->rotation[output] & XFCE_RANDR_ROTATIONS_MASK)
     {
@@ -541,7 +541,7 @@ xfce_randr_read_edid_data (Display *xdisplay,
 static gchar *
 xfce_randr_friendly_name (XfceRandr *randr,
                           guint output,
-                          guint output_rr_id)
+                          RROutput rr_output)
 {
     Display *xdisplay;
     MonitorInfo *info = NULL;
@@ -551,7 +551,7 @@ xfce_randr_friendly_name (XfceRandr *randr,
 
     /* get the vendor & size */
     xdisplay = gdk_x11_display_get_xdisplay (randr->priv->display);
-    edid_data = xfce_randr_read_edid_data (xdisplay, randr->priv->resources->outputs[output_rr_id]);
+    edid_data = xfce_randr_read_edid_data (xdisplay, rr_output);
 
     if (edid_data)
     {
@@ -561,8 +561,8 @@ xfce_randr_friendly_name (XfceRandr *randr,
     else
     {
         XRROutputInfo *xinfo = randr->priv->output_info[output];
-        gchar *edid_str = g_strdup_printf ("%s-%lu-%lu-%d-%d-%d",
-                                           xinfo->name, xinfo->mm_width, xinfo->mm_height,
+        gchar *edid_str = g_strdup_printf ("%lu-%lu-%d-%d-%d",
+                                           xinfo->mm_width, xinfo->mm_height,
                                            xinfo->ncrtc, xinfo->nclone, xinfo->nmode);
         randr->priv->edid[output] = g_compute_checksum_for_string (G_CHECKSUM_SHA1, edid_str, -1);
         g_free (edid_str);
@@ -712,7 +712,7 @@ xfce_randr_clonable_modes (XfceRandr *randr)
 
 
 
-gchar *
+const gchar *
 xfce_randr_get_edid (XfceRandr *randr,
                      guint noutput)
 {
@@ -721,7 +721,21 @@ xfce_randr_get_edid (XfceRandr *randr,
 
 
 
-gchar *
+const gchar *
+xfce_randr_get_edid_by_id (XfceRandr *randr,
+                           RROutput output)
+{
+    for (guint n = 0; n < randr->noutput; n++)
+    {
+        if (randr->priv->rr_outputs[n] == output)
+            return randr->priv->edid[n];
+    }
+    return NULL;
+}
+
+
+
+const gchar *
 xfce_randr_get_output_info_name (XfceRandr *randr,
                                  guint noutput)
 {
@@ -800,3 +814,17 @@ xfce_randr_mode_height (XfceRandr *randr,
     else
         return round (mode->height * randr->scaley[output]);
 }
+
+
+
+gdouble
+xfce_randr_calculate_refresh_rate (XRRModeInfo mode)
+{
+    gdouble v_total = mode.vTotal;
+    if (mode.modeFlags & RR_DoubleScan)
+        v_total *= 2.0;
+    if (mode.modeFlags & RR_Interlace)
+        v_total /= 2.0;
+
+    return mode.dotClock / ((gdouble) mode.hTotal * v_total);
+}
