@@ -26,8 +26,8 @@ G_BEGIN_DECLS
 #define XFCE_TYPE_DISPLAY_SETTINGS_X11 (xfce_display_settings_x11_get_type ())
 G_DECLARE_FINAL_TYPE (XfceDisplaySettingsX11, xfce_display_settings_x11, XFCE, DISPLAY_SETTINGS_X11, XfceDisplaySettings)
 
-XfceDisplaySettings *xfce_display_settings_x11_new (gboolean opt_minimal,
-                                                    GError **error);
+XfceDisplaySettings *
+xfce_display_settings_x11_new (GError **error);
 
 G_END_DECLS
 
