@@ -19,15 +19,18 @@
 #ifndef __XFCE_MIME_HELPER_UTILS_H__
 #define __XFCE_MIME_HELPER_UTILS_H__
 
+#include "xfce-mime-helper.h"
+
 #include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
-#include "xfce-mime-helper.h"
 
 G_BEGIN_DECLS
 
-gboolean xfce_mime_helper_category_from_string (const gchar       *string,
-                                          XfceMimeHelperCategory *category_return);
-gchar   *xfce_mime_helper_category_to_string   (XfceMimeHelperCategory  category) G_GNUC_MALLOC;
+gboolean
+xfce_mime_helper_category_from_string (const gchar *string,
+                                       XfceMimeHelperCategory *category_return);
+gchar *
+xfce_mime_helper_category_to_string (XfceMimeHelperCategory category) G_GNUC_MALLOC;
 
 G_END_DECLS
 
